@@ -661,9 +661,9 @@ def build_inline(
 
         # compile the cpp source code and load the module
         lib_path: str = tvm_ffi.cpp.build_inline(
-            name='hello',
+            name="hello",
             cpp_sources=cpp_source,
-            functions='add_one_cpu'
+            functions="add_one_cpu",
         )
 
         # load the module
@@ -751,7 +751,7 @@ def build_inline(
         )
 
 
-def load_inline(
+def load_inline(  # noqa: PLR0913
     name: str,
     *,
     cpp_sources: Sequence[str] | str | None = None,
@@ -763,6 +763,7 @@ def load_inline(
     extra_include_paths: Sequence[str] | None = None,
     build_directory: str | None = None,
     embed_cubin: Mapping[str, bytes] | None = None,
+    keep_module_alive: bool = True,
 ) -> Module:
     """Compile, build and load a C++/CUDA module from inline source code.
 
@@ -791,13 +792,13 @@ def load_inline(
 
     Parameters
     ----------
-    name: str
+    name
         The name of the tvm ffi module.
-    cpp_sources: Sequence[str] | str, optional
+    cpp_sources
         The C++ source code. It can be a list of sources or a single source.
-    cuda_sources: Sequence[str] | str, optional
+    cuda_sources
         The CUDA source code. It can be a list of sources or a single source.
-    functions: Mapping[str, str] | Sequence[str] | str, optional
+    functions
         The functions in cpp_sources or cuda_source that will be exported to the tvm ffi module. When a mapping is
         given, the keys are the names of the exported functions, and the values are docstrings for the functions
         (use an empty string to skip documentation for specific functions). When a sequence or a single string is given, they are
@@ -805,41 +806,48 @@ def load_inline(
         also be given as a string. When cpp_sources is given, the functions must be declared (not necessarily defined)
         in the cpp_sources. When cpp_sources is not given, the functions must be defined in the cuda_sources. If not
         specified, no function will be exported.
-    extra_cflags: Sequence[str], optional
+    extra_cflags
         The extra compiler flags for C++ compilation.
         The default flags are:
 
         - On Linux/macOS: ['-std=c++17', '-fPIC', '-O2']
         - On Windows: ['/std:c++17', '/O2']
 
-    extra_cuda_cflags: Sequence[str], optional
+    extra_cuda_cflags
         The extra compiler flags for CUDA compilation.
 
-    extra_ldflags: Sequence[str], optional
+    extra_ldflags
         The extra linker flags.
         The default flags are:
 
         - On Linux/macOS: ['-shared']
         - On Windows: ['/DLL']
 
-    extra_include_paths: Sequence[str], optional
+    extra_include_paths
         The extra include paths.
 
-    build_directory: str, optional
+    build_directory
         The build directory. If not specified, a default tvm ffi cache directory will be used. By default, the
         cache directory is ``~/.cache/tvm-ffi``. You can also set the ``TVM_FFI_CACHE_DIR`` environment variable to
         specify the cache directory.
 
-    embed_cubin: Mapping[str, bytes], optional
+    embed_cubin
         A mapping from CUBIN module names to CUBIN binary data. When provided, the CUBIN data will be embedded
         into the compiled shared library using objcopy, making it accessible via the TVM_FFI_EMBED_CUBIN macro.
         The keys should match the names used in TVM_FFI_EMBED_CUBIN calls in the C++ source code.
 
+    keep_module_alive
+        Whether to keep the module alive. If True, the module will be kept alive
+        for the duration of the program until libtvm_ffi.so is unloaded.
+
     Returns
     -------
     mod: Module
         The loaded tvm ffi module.
 
+    See Also
+    --------
+    :py:func:`tvm_ffi.load_module`
 
     Example
     -------
@@ -868,9 +876,9 @@ def load_inline(
 
         # compile the cpp source code and load the module
         mod: Module = tvm_ffi.cpp.load_inline(
-            name='hello',
+            name="hello",
             cpp_sources=cpp_source,
-            functions='add_one_cpu'
+            functions="add_one_cpu",
         )
 
         # use the function from the loaded module to perform
@@ -892,7 +900,8 @@ def load_inline(
             extra_include_paths=extra_include_paths,
             build_directory=build_directory,
             embed_cubin=embed_cubin,
-        )
+        ),
+        keep_module_alive=keep_module_alive,
     )
 
 
@@ -1008,8 +1017,8 @@ def build(
 
         # compile the cpp source file and get the library path
         lib_path: str = tvm_ffi.cpp.build(
-            name='my_ops',
-            cpp_files='my_ops.cpp'
+            name="my_ops",
+            cpp_files="my_ops.cpp",
         )
 
         # load the module
@@ -1045,6 +1054,7 @@ def load(
     extra_ldflags: Sequence[str] | None = None,
     extra_include_paths: Sequence[str] | None = None,
     build_directory: str | None = None,
+    keep_module_alive: bool = True,
 ) -> Module:
     """Compile, build and load a C++/CUDA module from source files.
 
@@ -1071,48 +1081,55 @@ def load(
 
     Parameters
     ----------
-    name: str
+    name
         The name of the tvm ffi module.
-    cpp_files: Sequence[str] | str, optional
+    cpp_files
         The C++ source files to compile. It can be a list of file paths or a single file path. Both absolute and
         relative paths are supported.
-    cuda_files: Sequence[str] | str, optional
+    cuda_files
         The CUDA source files to compile. It can be a list of file paths or a single file path. Both absolute and
         relative paths are supported.
-    extra_cflags: Sequence[str], optional
+    extra_cflags
         The extra compiler flags for C++ compilation.
         The default flags are:
 
         - On Linux/macOS: ['-std=c++17', '-fPIC', '-O2']
         - On Windows: ['/std:c++17', '/MD', '/O2']
 
-    extra_cuda_cflags: Sequence[str], optional
+    extra_cuda_cflags
         The extra compiler flags for CUDA compilation.
         The default flags are:
 
         - ['-Xcompiler', '-fPIC', '-std=c++17', '-O2'] (Linux/macOS)
         - ['-Xcompiler', '/std:c++17', '/O2'] (Windows)
 
-    extra_ldflags: Sequence[str], optional
+    extra_ldflags
         The extra linker flags.
         The default flags are:
 
         - On Linux/macOS: ['-shared', '-L<tvm_ffi_lib_path>', '-ltvm_ffi']
         - On Windows: ['/DLL', '/LIBPATH:<tvm_ffi_lib_path>', '<tvm_ffi_lib_name>.lib']
 
-    extra_include_paths: Sequence[str], optional
+    extra_include_paths
         The extra include paths for header files. Both absolute and relative paths are supported.
 
-    build_directory: str, optional
+    build_directory
         The build directory. If not specified, a default tvm ffi cache directory will be used. By default, the
         cache directory is ``~/.cache/tvm-ffi``. You can also set the ``TVM_FFI_CACHE_DIR`` environment variable to
         specify the cache directory.
 
+    keep_module_alive
+        Whether to keep the module alive. If True, the module will be kept alive
+        for the duration of the program until libtvm_ffi.so is unloaded.
+
     Returns
     -------
     mod: Module
         The loaded tvm ffi module.
 
+    See Also
+    --------
+    :py:func:`tvm_ffi.load_module`
 
     Example
     -------
@@ -1148,8 +1165,8 @@ def load(
 
         # compile the cpp source file and load the module
         mod: Module = tvm_ffi.cpp.load(
-            name='my_ops',
-            cpp_files='my_ops.cpp'
+            name="my_ops",
+            cpp_files="my_ops.cpp",
         )
 
         # use the function from the loaded module
@@ -1169,5 +1186,6 @@ def load(
             extra_ldflags=extra_ldflags,
             extra_include_paths=extra_include_paths,
             build_directory=build_directory,
-        )
+        ),
+        keep_module_alive=keep_module_alive,
     )
